<?php

/**
 * @file
 * Page callbacks for the commentrss module.
 */

/**
 * Generate a feed for the last 10 comments of a node.
 *
 * @param $node
 *   A node object.
 */
function commentrss_node_feed($node) {
  // Find the latest 10 visible comments on this node.
  // We do not have to check n.status = 1 specifically since we have already
  // performed a node_access('view', $node) check on this node.
  $sql = db_rewrite_sql("SELECT c.cid FROM {comments} c WHERE c.nid = %d AND c.status = %d ORDER BY c.cid DESC", 'c', 'cid');
  $query = db_query_range($sql, $node->nid, COMMENT_PUBLISHED, 0, variable_get('feed_default_items', 10));
  $cids = commentrss_fetch_col($query);

  // Fill channel information based on node details.
  $channel['title'] = t('@site - Comments for "@title"', array(
    '@site' => variable_get('site_name', 'Drupal'),
    '@title' => $node->title,
  ));
  $channel['description'] = t('Comments for "@title"', array('@title' => $node->title));
  $channel['link'] = url('node/' . $node->nid, array('absolute' => TRUE));

  return commentrss_feed($cids, $channel);
}
